@@ -2,7 +2,7 @@ from asyncio import get_running_loop
 from concurrent.futures.thread import ThreadPoolExecutor
 from contextvars import copy_context
 from functools import partial, wraps
-from inspect import iscoroutinefunction
+from inspect import isasyncgenfunction, iscoroutinefunction
 from typing import Any, Awaitable, Callable, TypeVar, cast
 
 T = TypeVar("T")
@@ -34,22 +34,35 @@ def async_wrapper(
     workers: ThreadPoolExecutor | None = None,
 ) -> Callable[..., Awaitable[T]]:
     if iscoroutinefunction(func):
+        # Native coroutine functions are already awaitable.
         return func
 
     @wraps(func)
     async def dummy(**params: Any) -> T:
         return func(**params)
 
-    try:
-        loop = get_running_loop()
-    except RuntimeError:
+    if isasyncgenfunction(func):
         return dummy
 
     @wraps(func)
     async def inner(**params: Any) -> T:
         ctx = copy_context()
         func_call = partial(ctx.run, func, **params)
+        # Resolve the running loop at call time to avoid cross-loop issues
+        # when the wrapper is created under a different event loop.
+        loop = get_running_loop()
         res = await loop.run_in_executor(workers, func_call)
         return cast(T, res)
 
-    return inner if threaded else dummy
+    # If there is no running loop at wrapper creation (e.g. created in sync context),
+    # prefer the non-threaded dummy; otherwise choose based on `threaded` flag.
+    try:
+        get_running_loop()
+        has_loop = True
+    except RuntimeError:
+        has_loop = False
+
+    if has_loop and threaded:
+        return inner
+
+    return dummy
