@@ -1,5 +1,9 @@
-from typing import Unpack
+from typing import ParamSpec, TypeVar
 
+from starlette.formparsers import MultiPartException as MultiPartException
+from starlette.requests import HTTPConnection as HTTPConnection
+from starlette.datastructures import URL as URL
+from starlette.datastructures import Address as Address
 from starlette.datastructures import FormData as FormData
 from starlette.datastructures import Headers as Headers
 from starlette.datastructures import QueryParams as QueryParams
@@ -9,6 +13,10 @@ from starlette.requests import cookie_parser as cookie_parser
 from starlette.responses import Response as Response
 from starlette.types import Lifespan as Lifespan
 from starlette.websockets import WebSocket as WebSocket
+from typing_extensions import Unpack
+
+P = ParamSpec("P")
+T = TypeVar("T")
 
 try:
     from starlette.testclient import TestClient as TestClient
@@ -20,7 +28,7 @@ from ididi import use as ididi_use
 from ididi.interfaces import INodeConfig, INodeFactory
 
 
-def use[**P, T](func: INodeFactory[P, T], **iconfig: Unpack[INodeConfig]):
+def use(func: INodeFactory[P, T], **iconfig: Unpack[INodeConfig]):
     if iconfig.get("reuse") is None:
         iconfig["reuse"] = False
     return ididi_use(func, **iconfig)
